@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -377,7 +377,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
 
     def list_instances(
         self,
-        request: cloud_redis.ListInstancesRequest = None,
+        request: Union[cloud_redis.ListInstancesRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -396,7 +396,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         are aggregated.
 
         Args:
-            request (google.cloud.redis_v1beta1.types.ListInstancesRequest):
+            request (Union[google.cloud.redis_v1beta1.types.ListInstancesRequest, dict]):
                 The request object. Request for
                 [ListInstances][google.cloud.redis.v1beta1.CloudRedis.ListInstances].
             parent (str):
@@ -468,7 +468,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
 
     def get_instance(
         self,
-        request: cloud_redis.GetInstanceRequest = None,
+        request: Union[cloud_redis.GetInstanceRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -478,7 +478,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         r"""Gets the details of a specific Redis instance.
 
         Args:
-            request (google.cloud.redis_v1beta1.types.GetInstanceRequest):
+            request (Union[google.cloud.redis_v1beta1.types.GetInstanceRequest, dict]):
                 The request object. Request for
                 [GetInstance][google.cloud.redis.v1beta1.CloudRedis.GetInstance].
             name (str):
@@ -538,7 +538,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
 
     def create_instance(
         self,
-        request: cloud_redis.CreateInstanceRequest = None,
+        request: Union[cloud_redis.CreateInstanceRequest, dict] = None,
         *,
         parent: str = None,
         instance_id: str = None,
@@ -563,7 +563,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         hours, so there is no need to call DeleteOperation.
 
         Args:
-            request (google.cloud.redis_v1beta1.types.CreateInstanceRequest):
+            request (Union[google.cloud.redis_v1beta1.types.CreateInstanceRequest, dict]):
                 The request object. Request for
                 [CreateInstance][google.cloud.redis.v1beta1.CloudRedis.CreateInstance].
             parent (str):
@@ -660,7 +660,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
 
     def update_instance(
         self,
-        request: cloud_redis.UpdateInstanceRequest = None,
+        request: Union[cloud_redis.UpdateInstanceRequest, dict] = None,
         *,
         update_mask: field_mask_pb2.FieldMask = None,
         instance: cloud_redis.Instance = None,
@@ -676,7 +676,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         there is no need to call DeleteOperation.
 
         Args:
-            request (google.cloud.redis_v1beta1.types.UpdateInstanceRequest):
+            request (Union[google.cloud.redis_v1beta1.types.UpdateInstanceRequest, dict]):
                 The request object. Request for
                 [UpdateInstance][google.cloud.redis.v1beta1.CloudRedis.UpdateInstance].
             update_mask (google.protobuf.field_mask_pb2.FieldMask):
@@ -766,7 +766,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
 
     def upgrade_instance(
         self,
-        request: cloud_redis.UpgradeInstanceRequest = None,
+        request: Union[cloud_redis.UpgradeInstanceRequest, dict] = None,
         *,
         name: str = None,
         redis_version: str = None,
@@ -778,7 +778,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         specified in the request.
 
         Args:
-            request (google.cloud.redis_v1beta1.types.UpgradeInstanceRequest):
+            request (Union[google.cloud.redis_v1beta1.types.UpgradeInstanceRequest, dict]):
                 The request object. Request for
                 [UpgradeInstance][google.cloud.redis.v1beta1.CloudRedis.UpgradeInstance].
             name (str):
@@ -860,7 +860,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
 
     def import_instance(
         self,
-        request: cloud_redis.ImportInstanceRequest = None,
+        request: Union[cloud_redis.ImportInstanceRequest, dict] = None,
         *,
         name: str = None,
         input_config: cloud_redis.InputConfig = None,
@@ -879,7 +879,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         few hours, so there is no need to call DeleteOperation.
 
         Args:
-            request (google.cloud.redis_v1beta1.types.ImportInstanceRequest):
+            request (Union[google.cloud.redis_v1beta1.types.ImportInstanceRequest, dict]):
                 The request object. Request for
                 [Import][google.cloud.redis.v1beta1.CloudRedis.ImportInstance].
             name (str):
@@ -961,7 +961,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
 
     def export_instance(
         self,
-        request: cloud_redis.ExportInstanceRequest = None,
+        request: Union[cloud_redis.ExportInstanceRequest, dict] = None,
         *,
         name: str = None,
         output_config: cloud_redis.OutputConfig = None,
@@ -976,7 +976,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         few hours, so there is no need to call DeleteOperation.
 
         Args:
-            request (google.cloud.redis_v1beta1.types.ExportInstanceRequest):
+            request (Union[google.cloud.redis_v1beta1.types.ExportInstanceRequest, dict]):
                 The request object. Request for
                 [Export][google.cloud.redis.v1beta1.CloudRedis.ExportInstance].
             name (str):
@@ -1058,7 +1058,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
 
     def failover_instance(
         self,
-        request: cloud_redis.FailoverInstanceRequest = None,
+        request: Union[cloud_redis.FailoverInstanceRequest, dict] = None,
         *,
         name: str = None,
         data_protection_mode: cloud_redis.FailoverInstanceRequest.DataProtectionMode = None,
@@ -1071,7 +1071,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         Memorystore for Redis instance.
 
         Args:
-            request (google.cloud.redis_v1beta1.types.FailoverInstanceRequest):
+            request (Union[google.cloud.redis_v1beta1.types.FailoverInstanceRequest, dict]):
                 The request object. Request for
                 [Failover][google.cloud.redis.v1beta1.CloudRedis.FailoverInstance].
             name (str):
@@ -1154,7 +1154,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
 
     def delete_instance(
         self,
-        request: cloud_redis.DeleteInstanceRequest = None,
+        request: Union[cloud_redis.DeleteInstanceRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1165,7 +1165,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         serving and data is deleted.
 
         Args:
-            request (google.cloud.redis_v1beta1.types.DeleteInstanceRequest):
+            request (Union[google.cloud.redis_v1beta1.types.DeleteInstanceRequest, dict]):
                 The request object. Request for
                 [DeleteInstance][google.cloud.redis.v1beta1.CloudRedis.DeleteInstance].
             name (str):
